=====================
Project Documentation
=====================

.. contents:: Contents
   :local:

Links to **information on usage, configuration and development** hosted on
Read The Docs or in the GitHub project repo.

Jupyter User Interfaces
-----------------------
* `Jupyter Notebook <https://jupyter-notebook.readthedocs.io/en/latest/>`_
* `jupyter_console <https://jupyter-console.readthedocs.io/en/latest/>`_
* `qtconsole <https://qtconsole.readthedocs.io/en/stable/>`_

JupyterHub
----------
* `JupyterHub <https://jupyterhub.readthedocs.io/en/latest/>`_
* `configurable-http-proxy <https://github.com/jupyterhub/configurable-http-proxy>`_
* `dockerspawner <https://github.com/jupyterhub/dockerspawner>`_
* `ldapauthenticator <https://github.com/jupyterhub/ldapauthenticator>`_
* `oauthenticator <https://github.com/jupyterhub/oauthenticator>`_
* `sudospawner <https://github.com/jupyterhub/sudospawner>`_

Education
---------
* `nbgrader <https://nbgrader.readthedocs.io/en/latest/>`_

Execution
---------
* `nbclient <https://nbclient.readthedocs.io/en/latest/>`_

Notebook Conversion and Formatting
----------------------------------
* `nbconvert <https://nbconvert.readthedocs.io/en/latest/>`_
* `nbformat <https://nbformat.readthedocs.io/en/latest/>`_

Kernels
-------
* `IPython <https://ipython.readthedocs.io/en/stable/>`_
* `IRkernel <https://irkernel.github.io/>`_
* `IJulia <https://github.com/JuliaLang/IJulia.jl>`_
* `List of community maintained language kernels <https://github.com/ipython/ipython/wiki/IPython-kernels-for-other-languages>`_

IPython
-------
* `IPython`_
* `ipykernel <https://ipython.readthedocs.io/en/stable/>`_
* `ipyparallel <https://ipyparallel.readthedocs.io/en/latest/>`_

Deployment
----------
* `docker-stacks <https://github.com/jupyter/docker-stacks>`_
* `ipywidgets <https://ipywidgets.readthedocs.io/en/latest/>`_
* `jupyter-drive <https://github.com/jupyter/jupyter-drive>`_
* `jupyter-sphinx-theme <https://github.com/jupyter/jupyter-sphinx-theme>`_
* `kernel_gateway <https://jupyter-kernel-gateway.readthedocs.io/en/latest/>`_
* `nbviewer <https://github.com/jupyter/nbviewer>`_
* `tmpnb <https://github.com/jupyter/tmpnb>`_
* `traitlets <https://traitlets.readthedocs.io/en/stable/>`_

JupyterLab
----------
* `jupyter-js-notebook <https://github.com/jupyter/jupyter-js-notebook>`_
* `jupyter-js-phosphide <https://github.com/jupyter/jupyter-js-phosphide>`_
* `jupyter-js-plugins <https://github.com/jupyter/jupyter-js-plugins>`_
* `jupyter-js-services <http://jupyter.org/jupyter-js-services/>`_
* `jupyter-js-ui <http://jupyter.org/jupyter-js-ui/>`_
* `jupyter-js-utils <http://jupyter.org/jupyter-js-utils/>`_

Architecture
------------
* `jupyter_client <https://jupyter-client.readthedocs.io/en/latest/>`_
* `jupyter_core <https://jupyter-core.readthedocs.io/en/latest/>`_
